==> gnome-flashback-3.49.1.tar.xz: gnome-flashback-3.49.1/README.md <==
# About

GNOME Flashback is the backend of the GNOME Flashback desktop session. It 
provides the `gnome-flashback` and `gnome-flashback-clipboard` programs.
In addition, GNOME Flashback contains the `system-indicators` library.

## gnome-flashback

The `gnome-flashback` program contains a set of D-Bus backends that are used by
the GNOME Flashback desktop, they include the following:

* Accessibility Keyboard
* Audio Device Selection
* Automount Manager
* Desktop
* End Session Dialog
* Idle Monitor
* Input Settings
* Input Sources
* Notifications
* Policykit
* Root Background
* Screencast
* Screensaver
* Screenshot
* Shell
* Sound Applet
* Status Notifier Watcher

## Daemons

The `gnome-flashback-clipboard` is a daemon that provices clipboard
functionality.

## System Indicators

The `system-indicators` is a module that can be loaded by GNOME Panel
to display various system indicators such as:

* Bluetooth
* Desktop Menu Items
* Indicators
* Power
* Volume Settings

# Releases

You may download gnome-flashback releases and updates from the
[release server](http://download.gnome.org/sources/gnome-flashback/)

# Discussions

To discuss gnome-panel, you may use the
[gnome-flashback-list](http://mail.gnome.org/mailman/listinfo/gnome-flashback-list) mailing list.

# How to report bugs

Bugs should be reported in the issue section of
[GNOME Gitlab](https://gitlab.gnome.org/GNOME/gnome-flashback/issues)

You will need to create an account for yourself.

Please read the HACKING file for information on where to send changes or
bugfixes for this package.

==> gnome-flashback_3.58.0.orig.tar.xz: gnome-flashback-3.58.0/README.md <==
# About

GNOME Flashback is the backend of the GNOME Flashback desktop session. It 
provides the `gnome-flashback` and `gnome-flashback-clipboard` programs.
In addition, GNOME Flashback contains the `system-indicators` library.

## gnome-flashback

The `gnome-flashback` program contains a set of D-Bus backends that are used by
the GNOME Flashback desktop, they include the following:

* Accessibility Keyboard
* Audio Device Selection
* Automount Manager
* Desktop
* End Session Dialog
* Idle Monitor
* Input Settings
* Input Sources
* Notifications
* Policykit
* Root Background
* Screencast
* Screensaver
* Screenshot
* Shell
* Sound Applet
* Status Notifier Watcher

## Daemons

The `gnome-flashback-clipboard` is a daemon that provices clipboard
functionality.

## System Indicators

The `system-indicators` is a module that can be loaded by GNOME Panel
to display various system indicators such as:

* Bluetooth
* Desktop Menu Items
* Indicators
* Power
* Volume Settings

# Releases

You may download gnome-flashback releases and updates from the
[release server](https://download.gnome.org/sources/gnome-flashback/)

# Discussions

To discuss gnome-panel, you may use the
[discussion forum](https://discourse.gnome.org/).

# How to report bugs

Bugs should be reported in the issue section of
[GNOME Gitlab](https://gitlab.gnome.org/GNOME/gnome-flashback/issues)

You will need to create an account for yourself.

Please read the HACKING file for information on where to send changes or
bugfixes for this package.
